@@ -3,8 +3,8 @@ import hashlib
 
 class Encrypt:
 
-
-	def md5(self,str):
+	@staticmethod
+	def md5(str):
 		hashlib_md5 = hashlib.md5()
 		hashlib_md5.update(str.encode(encoding='utf-8'))
 		return hashlib_md5.hexdigest()
\ No newline at end of file
